@@ -45,24 +45,24 @@ mutate..data.frame <- function(.df, ..., .by = NULL, by = NULL) {
     for (i in seq_along(dots)) {
 
       .col_name <- all_names[[i]]
-      val <- dots[i][[1]]
+      .val <- dots[[i]]
 
-      data_env <- env(quo_get_env(dots[[i]]), .df = .df)
+      data_env <- env(quo_get_env(.val), .df = .df)
 
       # Prevent modify-by-reference if the column already exists in the data.table
       # Fixes cases when user supplies a single value ex. 1, -1, "a"
       # !quo_is_null(val) allows for columns to be deleted using mutate.(.df, col = NULL)
-      if (.col_name %in% names(.df) && !quo_is_null(val)) {
+      if (.col_name %in% names(.df) && !quo_is_null(.val)) {
 
         eval_quo(
-          .df[, !!.col_name := vctrs::vec_recycle(!!val, .N)],
+          .df[, !!.col_name := vctrs::vec_recycle(!!.val, .N)],
           new_data_mask(data_env), caller_env()
         )
 
       } else {
 
         eval_quo(
-          .df[, !!.col_name := !!val],
+          .df[, !!.col_name := !!.val],
           new_data_mask(data_env), caller_env()
         )
       }
@@ -87,7 +87,8 @@ mutate..data.frame <- function(.df, ..., .by = NULL, by = NULL) {
 }
 
 #' @export
-#' @rdname mutate.
+#' @rdname dt_verb
+#' @inheritParams mutate.
 dt_mutate <- function(.df, ..., .by = NULL, by = NULL) {
   deprecate_soft("0.5.2", "tidytable::dt_mutate()", "mutate.()")
 
