@@ -20,23 +20,25 @@
 #' test_df %>%
 #'   mutate.(count = n.())
 n. <- function() {
-  deprecate_soft("0.5.3", "tidytable::n.()",
-                 details = paste(
-                   c("Using n.() is much slower than the data.table helper .N and should be avoided.",
-                     "",
-                     "  # Good",
-                     "  df %>% summarize.(count = .N)",
-                     "",
-                     "  # Bad",
-                     "  df %>% summarize.(count = n.())"), collapse = "\n"))
 
   eval_tidy(expr(.N), env = caller_env())
 }
 
 #' @export
-#' @rdname n.
+#' @rdname dt_verb
+#' @inheritParams n.
 dt_n <- function() {
   deprecate_soft("0.5.2", "tidytable::dt_n()", "n.()")
 
   n.()
 }
+
+# deprecate_soft("0.5.3", "tidytable::n.()",
+#                details = paste(
+#                  c("Using n.() is much slower than the data.table helper .N and should be avoided.",
+#                    "",
+#                    "  # Good",
+#                    "  df %>% summarize.(count = .N)",
+#                    "",
+#                    "  # Bad",
+#                    "  df %>% summarize.(count = n.())"), collapse = "\n"))
