@@ -8,6 +8,10 @@
 #' @param .fns Functions to pass. Can pass a list of functions.
 #' @param ... Other arguments for the passed function
 #' @param .by Columns to group by
+#' @param .names A glue specification that helps with renaming output columns.
+#' `{.col}` stands for the selected column, and `{.fn}` stands for the name of the function being applied.
+#' The default (`NULL`) is equivalent to `"{.col}"` for a single function case and "`{.col}_{.fn}`"
+#' when a list is used for `.fns`.
 #' @param by This argument has been renamed to .by and is deprecated
 #'
 #' @md
@@ -18,7 +22,7 @@
 #'                       b = 4:6,
 #'                       z = c("a", "a", "b"))
 #'
-#' # Single function
+#' # Pass a single function
 #' test_df %>%
 #'   summarize_across.(c(a, b), mean, na.rm = TRUE)
 #'
@@ -34,14 +38,24 @@
 #' test_df %>%
 #'   summarize_across.(c(a, b),
 #'                     list(avg = mean,
-#'                          max_plus_one = ~ max(.x) + 1),
+#'                          max = ~ max(.x)),
 #'                     .by = z)
-summarize_across. <- function(.df, .cols = everything(), .fns, ..., .by = NULL, by = NULL) {
+#'
+#' # Use the `.names` argument for more naming control
+#' test_df %>%
+#'   summarize_across.(c(a, b),
+#'                     list(avg = mean,
+#'                          max = ~ max(.x)),
+#'                     .by = z,
+#'                     .names = "{.col}_test_{.fn}")
+summarize_across. <- function(.df, .cols = everything(), .fns, ...,
+                              .by = NULL, .names = NULL, by = NULL) {
   UseMethod("summarize_across.")
 }
 
 #' @export
-summarize_across..data.frame <- function(.df, .cols = everything(), .fns, ..., .by = NULL, by = NULL) {
+summarize_across..data.frame <- function(.df, .cols = everything(), .fns, ...,
+                                         .by = NULL, .names = NULL, by = NULL) {
 
   .df <- as_tidytable(.df)
 
@@ -50,37 +64,43 @@ summarize_across..data.frame <- function(.df, .cols = everything(), .fns, ..., .
   .by <- check_dot_by(enquo(.by), enquo(by), "summarize_across.")
   .by <- select_vec_chr(.df, !!.by)
 
+  .cols <- .cols[.cols %notin% .by]
+
   if (length(.cols) == 0) abort("No columns have been selected to summarize.()")
 
-  # Needed to ensure summarize_across.() doesn't fail due to
-  # integer results in one group but double results in another group
-  # .df <- mutate_across.(.df, where(is.numeric), as.double)
-
   if (!is.list(.fns)) {
 
+    if (!is.null(.names)) summarize_across_warning()
+
+    .names <- .names %||% "{.col}"
+
+    .col_names <- vec_as_names(
+      glue(.names, .col = .cols, .fn = "1", col = .cols, fn = "1"),
+      repair = "check_unique", quiet = TRUE
+    )
+
     .fns <- as_function(.fns)
 
     .df <- eval_quo(
       .df[, lapply(.SD, .fns, ...), .SDcols = .cols, by = .by]
     )
 
+    names(.df) <- c(.by, .col_names)
+
   } else {
 
+    summarize_across_warning()
+
+    # Make new names
     names_flag <- have_name(.fns)
 
-    if (!all(names_flag)) {
+    if (!all(names_flag)) names(.fns)[!names_flag] <- seq_len(length(.fns))[!names_flag]
 
-      # If some functions are unnamed, create names
-      # The resulting names are prefixed with "fn" instead of suffixed
-      # Prefixing is the data.table default when providing names,
-      # which is different than dplyr but might not be worth fixing
-      names(.fns)[!names_flag] <- "fn"
+    fn_names <- names(.fns)
 
-      fixed_names <- vec_as_names(names(.fns), repair = "unique", quiet = TRUE)
-      fixed_names <- str_replace.(fixed_names, "\\...", "")
+    .names <- .names %||% "{.col}_{.fn}"
 
-      names(.fns) <- fixed_names
-    }
+    new_names <- unlist(map.(fn_names, ~ glue(.names, .col = .cols, .fn = .x, col = .cols, fn = .x)))
 
     # Convert .fns to list of map./lapply calls
     .fns <- map.(.fns, ~ call2('map.', quo(.SD), .x))
@@ -89,10 +109,7 @@ summarize_across..data.frame <- function(.df, .cols = everything(), .fns, ..., .
       .df[, c(!!!.fns), .SDcols = .cols, by = .by]
     )
 
-    old_names <- names(.df)
-    new_names <- str_replace.(old_names, "[.]", "_")
-
-    setnames(.df, old_names, new_names)
+    names(.df) <- c(.by, new_names)
   }
   .df
 }
@@ -100,3 +117,16 @@ summarize_across..data.frame <- function(.df, .cols = everything(), .fns, ..., .
 #' @export
 #' @rdname summarize_across.
 summarise_across. <- summarize_across.
+
+summarize_across_warning <- function() {
+
+  warn(
+    paste(
+      c("As of tidytable v0.5.4, column names generated by summarize_across.() follow",
+        "dplyr summarize(across()) conventions of using suffixes instead of prefixes. This may",
+        "require updates to older versions of your code."),
+      collapse = "\n"),
+    .frequency = "regularly",
+    .frequency_id = "summarize_across_names"
+  )
+}
