@@ -1,5 +1,19 @@
+setup(options(lifecycle_verbosity = "quiet"))
 
 ##### bind_rows.()
+test_that("dt_bind_rows() works with data.tables & is deprecated", {
+  df1 <- data.table(x = c(1,2,3), y = c(3,4,5))
+  df2 <- data.table(x = c(1,2,3), y = c(3,4,5))
+
+  bind_df <- df1 %>%
+    dt_bind_rows(df2)
+
+  expect_named(bind_df, c("x","y"))
+  expect_equal(bind_df$x, c(1,2,3,1,2,3))
+  expect_equal(bind_df$y, c(3,4,5,3,4,5))
+  expect_deprecated(dt_bind_rows(df1, df2))
+})
+
 test_that("bind_rows.() works with data.tables", {
   df1 <- data.table(x = c(1,2,3), y = c(3,4,5))
   df2 <- data.table(x = c(1,2,3), y = c(3,4,5))
@@ -12,18 +26,6 @@ test_that("bind_rows.() works with data.tables", {
   expect_equal(bind_df$y, c(3,4,5,3,4,5))
 })
 
-test_that("dt_bind_rows() works with data.tables", {
-  df1 <- data.table(x = c(1,2,3), y = c(3,4,5))
-  df2 <- data.table(x = c(1,2,3), y = c(3,4,5))
-
-  bind_df <- df1 %>%
-    dt_bind_rows(df2)
-
-  expect_named(bind_df, c("x","y"))
-  expect_equal(bind_df$x, c(1,2,3,1,2,3))
-  expect_equal(bind_df$y, c(3,4,5,3,4,5))
-})
-
 test_that("bind_rows.() works with data.frames", {
   df1 <- data.frame(x = c(1,2,3), y = c(3,4,5))
   df2 <- data.frame(x = c(1,2,3), y = c(3,4,5))
@@ -51,13 +53,14 @@ test_that("bind_rows.() works with a list", {
 
 
 ##### bind_cols.()
-test_that("bind_cols.() works with data.tables", {
+test_that("dt_bind_cols() works with data.tables & is deprecated", {
   df1 <- data.table(x = c(1,2,3), y = c(3,4,5))
   df2 <- data.table(a = c(1,2,3), b = c(3,4,5))
 
   bind_df <- df1 %>%
-    bind_cols.(df2)
+    dt_bind_cols(df2)
 
+  expect_deprecated(dt_bind_cols(df1, df2))
   expect_named(bind_df, c("x","y","a","b"))
   expect_equal(bind_df$x, c(1,2,3))
   expect_equal(bind_df$y, c(3,4,5))
@@ -65,12 +68,12 @@ test_that("bind_cols.() works with data.tables", {
   expect_equal(bind_df$b, c(3,4,5))
 })
 
-test_that("dt_bind_cols() works with data.tables", {
+test_that("bind_cols.() works with data.tables", {
   df1 <- data.table(x = c(1,2,3), y = c(3,4,5))
   df2 <- data.table(a = c(1,2,3), b = c(3,4,5))
 
   bind_df <- df1 %>%
-    dt_bind_cols(df2)
+    bind_cols.(df2)
 
   expect_named(bind_df, c("x","y","a","b"))
   expect_equal(bind_df$x, c(1,2,3))
