@@ -1,3 +1,25 @@
+setup(options(lifecycle_verbosity = "quiet"))
+
+test_that("dt_case works & is deprecated", {
+
+  set.seed(843)
+  x <- rnorm(1e5)
+
+  cased <- dt_case(
+    x < median(x), "low",
+    x >= median(x), "high",
+    is.na(x), "other"
+  )
+
+  expect_deprecated(dt_case(x < 1, "low"))
+  expect_named(table(cased), c("high", "low"))
+  expect_error(dt_case(x < median(x), "three",
+                       default = x))
+  expect_equal(head(cased),
+               c("low","low","low","low","low","high"))
+
+})
+
 test_that("case. works", {
 
   set.seed(843)
@@ -18,25 +40,6 @@ test_that("case. works", {
 
 })
 
-test_that("dt_case works", {
-
-  set.seed(843)
-  x <- rnorm(1e5)
-
-  cased <- dt_case(
-      x < median(x), "low",
-      x >= median(x), "high",
-      is.na(x), "other"
-    )
-
-  expect_named(table(cased), c("high", "low"))
-  expect_error(dt_case(x < median(x), "three",
-                            default = x))
-  expect_equal(head(cased),
-               c("low","low","low","low","low","high"))
-
-})
-
 test_that("case. isn't tripped up by NA results v1", {
 
   test_df <- tidytable(x = c(1, NA, 1, 2))
