@@ -26,13 +26,26 @@ test_that("doesn't return NAs", {
   expect_equal(sliced_df, test_df)
 })
 
+test_that("works with gaps & doesn't return NAs", {
+  test_df <- tidytable(x = c(1,2,3,4), y = c(4,5,6,7), z = c("a", "a", "a", "b"))
+
+  sliced_df <- test_df %>%
+    slice.(c(1,3,5))
+
+  expect_equal(sliced_df$x, c(1,3))
+})
+
 test_that("works without .by with .N", {
   test_df <- tidytable(x = c(1,2,3,4), y = c(4,5,6,7), z = c("a", "a", "a", "b"))
 
   sliced_df <- test_df %>%
-    slice.(1:.N)
+    slice.(2:.N)
 
-  expect_equal(sliced_df, head(test_df, 4))
+  comp_df <- test_df %>%
+    head(4) %>%
+    tail(3)
+
+  expect_equal(sliced_df, comp_df)
 })
 
 test_that("works without .by with n.()", {
@@ -66,6 +79,7 @@ test_that("works with .by", {
   sliced_df <- test_df %>%
     slice.(1, .by = z)
 
+  expect_named(sliced_df, names(test_df))
   expect_equal(sliced_df$z, c("a", "b"))
   expect_equal(sliced_df$x, c(1, 4))
   expect_equal(sliced_df$y, c(4, 7))
@@ -107,7 +121,7 @@ test_that("works in custom function", {
 
   slice_fn <- function(.df, val) {
     .df %>%
-      slice.({{ val }}, .by = z)
+      slice.(val, .by = z)
   }
 
   sliced_df <- test_df %>%
@@ -153,16 +167,33 @@ test_that("_head.() works with n specified", {
   expect_equal(sliced_df, head(test_df, 3))
 })
 
-test_that("_head.() works with n specified", {
+test_that("_head.() works with n specified with by", {
   test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
 
-  datatable_df <- test_df[, head(.SD, 3), by = z]
-  sliced_df <- test_df %>%
-    dt_slice_head(n = 3, .by = z)
+  col_order <- names(test_df)
 
+  datatable_df <- test_df[, head(.SD, 3), by = z][, ..col_order]
+  sliced_df <- test_df %>%
+    slice_head.(n = 3, .by = z)
+
+  expect_named(sliced_df, names(test_df))
   expect_equal(datatable_df, sliced_df)
 })
 
+test_that("_head.() works in custom function", {
+  test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
+
+  slice_head_fn <- function(.df, val) {
+    .df %>%
+      slice_head.(val)
+  }
+
+  sliced_df <- test_df %>%
+    slice_head_fn(3)
+
+  expect_equal(sliced_df, head(test_df, 3))
+})
+
 # slice_tail.() ----------------------------------------------------
 
 test_that("dt_slice_tail() works when empty", {
@@ -190,7 +221,7 @@ test_that("_tail.() works with n specified", {
   expect_equal(sliced_df, tail(test_df, 3))
 })
 
-test_that("_tail.() works with n specified", {
+test_that("_tail.() works with n.()", {
   test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
   sliced_df <- test_df %>%
     slice_tail.(n = n.())
@@ -201,13 +232,30 @@ test_that("_tail.() works with n specified", {
 test_that("_tail() works with n specified with .by", {
   test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
 
-  datatable_df <- test_df[, tail(.SD, 3), by = z]
+  col_order <- names(test_df)
+
+  datatable_df <- test_df[, tail(.SD, 3), by = z][, ..col_order]
   sliced_df <- test_df %>%
     slice_tail.(n = 3, .by = z)
 
+  expect_named(sliced_df, names(test_df))
   expect_equal(datatable_df, sliced_df)
 })
 
+test_that("_tail.() works with a custom function", {
+  test_df <- tidytable(x = 1:10, y = 20:11, z = c(rep("a", 6), rep("b", 4)))
+
+  slice_tail_fn <- function(.df, val) {
+    .df %>%
+      slice_tail.(val)
+  }
+
+  sliced_df <- test_df %>%
+    slice_tail_fn(3)
+
+  expect_equal(sliced_df, tail(test_df, 3))
+})
+
 # slice_min.() ----------------------------------------------------
 
 test_that("dt_slice_min() works", {
@@ -233,6 +281,7 @@ test_that("_min.() works with .by", {
   sliced_df <- test_df %>%
     slice_min.(order_by = x, n = 3, .by = z)
 
+  expect_named(sliced_df, names(test_df))
   expect_equal(sliced_df$z, c("a", "a", "a", "b", "b", "b"))
   expect_equal(sliced_df$y, c(20,19,18,14,13,12))
 })
@@ -251,7 +300,7 @@ test_that("_max.() works with custom function with quosures", {
 
   slice_fn <- function(.df, col, num) {
     .df %>%
-      slice_max.({{ col }}, {{ num }})
+      slice_max.({{ col }}, num)
   }
 
   sliced_df <- test_df %>%
